Changelog
=========

0.3.0 (2016-07-01)
------------------

- Class based. [Michael Pfister]

- Nicer readme. [Michael Pfister]

0.2.5 (2016-06-30)
------------------

- Bugfix: missing packages in setup.py. [Michael Pfister]

- Bugfix: missing packages in setup.py. [Michael Pfister]

0.2.4 (2016-06-30)
------------------

- Updated setup. [Michael Pfister]

0.2.3 (2016-06-30)
------------------

- Updated setup. [Michael Pfister]

0.2.2 (2016-06-30)
------------------

- Updated setup. [Michael Pfister]

- Some cleaning. [Michael Pfister]

- Readme. [Michael Pfister]

- Readme. [Michael Pfister]

0.2.1 (2016-06-30)
------------------

- Pip naming conventions and version. [Michael Pfister]

- Pip naming conventions. [Michael Pfister]

- Format readme. [Michael Pfister]

- Format readme. [Michael Pfister]

- Initial commit. [Michael Pfister]
